pub struct LumaMaskNode { /* private fields */ }Expand description
Mask inputs[0] using the BT.709 luma of the source frame (inputs[1]).
The luma (0.0–1.0) is multiplied into the base alpha channel. The source frame is sampled per frame rather than baked into the node (#1710), which is what lets an effect graph containing this node be cached across frames.
Implementations